==> multiroute-tour-navigator-1.0.2.tgz: package/lib/MultiRouteTour.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
import { jsx as _jsx } from "react/jsx-runtime";
import { useMemo } from 'react';
import { useLocation, useNavigate } from 'react-router-dom';
import TourNavigator from 'tour-navigator';
export default function MultiRouteTour(_a) {
    var id = _a.id, steps = _a.steps, _b = _a.startAt, startAt = _b === void 0 ? TourNavigator.defaultProps.startAt || 0 : _b, _c = _a.nextStepCount, nextStepCount = _c === void 0 ? 0 : _c, nextStepRoute = _a.nextStepRoute, number = _a.number, _d = _a.replace, replace = _d === void 0 ? true : _d, props = __rest(_a, ["id", "steps", "startAt", "nextStepCount", "nextStepRoute", "number", "replace"]);
    var navigate = useNavigate();
    var _e = useLocation(), state = _e.state, pathname = _e.pathname;
    var __multiRouteTour = (state === null || state === void 0 ? void 0 : state.__multiRouteTour) || [];
    var lastState = __multiRouteTour[__multiRouteTour.length - 1];
    var currentStateIndex = number == undefined ? (__multiRouteTour.length - ((lastState === null || lastState === void 0 ? void 0 : lastState.id) == id ? 1 : 0)) : number - 1;
    var previousStateIndex = currentStateIndex - 1;
    var previousState = __multiRouteTour === null || __multiRouteTour === void 0 ? void 0 : __multiRouteTour[previousStateIndex];
    var currentState = __multiRouteTour === null || __multiRouteTour === void 0 ? void 0 : __multiRouteTour[currentStateIndex];
    if ((currentState === null || currentState === void 0 ? void 0 : currentState.id) != id) {
        currentState = {
            id: id,
            focusAt: ((previousState === null || previousState === void 0 ? void 0 : previousState.previousStepCount) + (previousState === null || previousState === void 0 ? void 0 : previousState.stepCount) + startAt) || 0,
            stepRoute: pathname,
            stepCount: steps.length,
            previousStepCount: ((previousState === null || previousState === void 0 ? void 0 : previousState.previousStepCount) + (previousState === null || previousState === void 0 ? void 0 : previousState.stepCount)) || 0,
            previousStepRoute: (previousState === null || previousState === void 0 ? void 0 : previousState.stepRoute) || null,
        };
    }
    var modifiedSteps = useMemo(function () {
        return __spreadArray(__spreadArray(__spreadArray([], Array(currentState.previousStepCount).fill(steps[0]), true), steps, true), Array(nextStepCount).fill(steps[steps.length - 1]), true);
    }, [steps]);
    var handleNext = function (helperProps) {
        var _a;
        var lastStepForThisRoute = currentState.previousStepCount + currentState.stepCount;
        var isLast = helperProps.currentStepIndex == lastStepForThisRoute;
        if (nextStepRoute && isLast) {
            var newState = __spreadArray([], __multiRouteTour, true);
            if ((lastState === null || lastState === void 0 ? void 0 : lastState.id) != id)
                newState.push(currentState);
            navigate(nextStepRoute, {
                state: {
                    __multiRouteTour: newState
                },
                replace: replace
            });
        }
        else {
            currentState.focusAt = helperProps.currentStepIndex;
            (_a = props.onNext) === null || _a === void 0 ? void 0 : _a.call(props, helperProps);
        }
    };
    var handlePrev = function (helperProps) {
        var _a;
        var isFirst = helperProps.currentStepIndex == (currentState.previousStepCount - 1);
        if (previousState && isFirst) {
            navigate(currentState.previousStepRoute, {
                state: { __multiRouteTour: __multiRouteTour.filter(function (item) { return item.id != id; }) },
                replace: replace
            });
        }
        else {
            currentState.focusAt = helperProps.currentStepIndex;
            (_a = props.onPrev) === null || _a === void 0 ? void 0 : _a.call(props, helperProps);
        }
    };
    if (currentStateIndex != 0 && !previousState)
        return null;
    return (_jsx(TourNavigator, __assign({}, props, { id: id, steps: modifiedSteps, startAt: currentState.focusAt, onNext: handleNext, onPrev: handlePrev })));
}

==> multiroute-tour-navigator-1.0.8.tgz: package/lib/MultiRouteTour.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
import { jsx as _jsx } from "react/jsx-runtime";
import { useMemo } from 'react';
import TourNavigator from 'tour-navigator';
export default function MultiRouteTour(_a) {
    var id = _a.id, steps = _a.steps, _b = _a.startAt, startAt = _b === void 0 ? TourNavigator.defaultProps.startAt || 0 : _b, _c = _a.nextStepCount, nextStepCount = _c === void 0 ? 0 : _c, nextStepRoute = _a.nextStepRoute, number = _a.number, _d = _a.replace, replace = _d === void 0 ? true : _d, navigate = _a.navigate, location = _a.location, props = __rest(_a, ["id", "steps", "startAt", "nextStepCount", "nextStepRoute", "number", "replace", "navigate", "location"]);
    var state = location.state, pathname = location.pathname;
    var __multiRouteTour = (state === null || state === void 0 ? void 0 : state.__multiRouteTour) || [];
    var lastState = __multiRouteTour[__multiRouteTour.length - 1];
    var currentStateIndex = number == undefined ? (__multiRouteTour.length - ((lastState === null || lastState === void 0 ? void 0 : lastState.id) == id ? 1 : 0)) : number - 1;
    var previousStateIndex = currentStateIndex - 1;
    var previousState = __multiRouteTour === null || __multiRouteTour === void 0 ? void 0 : __multiRouteTour[previousStateIndex];
    var currentState = __multiRouteTour === null || __multiRouteTour === void 0 ? void 0 : __multiRouteTour[currentStateIndex];
    if ((currentState === null || currentState === void 0 ? void 0 : currentState.id) != id) {
        currentState = {
            id: id,
            focusAt: ((previousState === null || previousState === void 0 ? void 0 : previousState.previousStepCount) + (previousState === null || previousState === void 0 ? void 0 : previousState.stepCount) + startAt) || 0,
            stepRoute: pathname,
            stepCount: steps.length,
            previousStepCount: ((previousState === null || previousState === void 0 ? void 0 : previousState.previousStepCount) + (previousState === null || previousState === void 0 ? void 0 : previousState.stepCount)) || 0,
            previousStepRoute: (previousState === null || previousState === void 0 ? void 0 : previousState.stepRoute) || null,
        };
    }
    var modifiedSteps = useMemo(function () {
        return __spreadArray(__spreadArray(__spreadArray([], Array(currentState.previousStepCount).fill(steps[0]), true), steps, true), Array(nextStepCount).fill(steps[steps.length - 1]), true);
    }, [steps]);
    var handleNext = function (helperProps) {
        var _a;
        var lastStepForThisRoute = currentState.previousStepCount + currentState.stepCount;
        var isLast = helperProps.currentStepIndex == lastStepForThisRoute;
        if (nextStepRoute && isLast) {
            var newState = __spreadArray([], __multiRouteTour, true);
            if ((lastState === null || lastState === void 0 ? void 0 : lastState.id) != id)
                newState.push(currentState);
            navigate(nextStepRoute, {
                state: {
                    __multiRouteTour: newState
                },
                replace: replace
            });
        }
        else {
            currentState.focusAt = helperProps.currentStepIndex;
            (_a = props.onNext) === null || _a === void 0 ? void 0 : _a.call(props, helperProps);
        }
    };
    var handlePrev = function (helperProps) {
        var _a;
        var isFirst = helperProps.currentStepIndex == (currentState.previousStepCount - 1);
        if (previousState && isFirst) {
            navigate(currentState.previousStepRoute, {
                state: { __multiRouteTour: __multiRouteTour.filter(function (item) { return item.id != id; }) },
                replace: replace
            });
        }
        else {
            currentState.focusAt = helperProps.currentStepIndex;
            (_a = props.onPrev) === null || _a === void 0 ? void 0 : _a.call(props, helperProps);
        }
    };
    if (currentStateIndex != 0 && !previousState)
        return null;
    return (_jsx(TourNavigator, __assign({}, props, { id: id, steps: modifiedSteps, startAt: currentState.focusAt, onNext: handleNext, onPrev: handlePrev })));
}
